/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 1.3.11u-20020813-2335
 * 
 * This file is not intended to be easily readable and contains a number of 
 * coding conventions designed to improve portability and efficiency. Do not make
 * changes to this file unless you know what you are doing--modify the SWIG 
 * interface file instead. 
 * ----------------------------------------------------------------------------- */

/***********************************************************************
 * common.swg
 *
 *     This file contains generic SWIG runtime support for pointer
 *     type checking as well as a few commonly used macros to control
 *     external linkage.
 *
 * Author : David Beazley (beazley@cs.uchicago.edu)
 *
 * Copyright (c) 1999-2000, The University of Chicago
 * 
 * This file may be freely redistributed without license or fee provided
 * this copyright message remains intact.
 ************************************************************************/

#include <string.h>
#include "suffix_tree.h"

#if defined(_WIN32) || defined(__WIN32__)
#       if defined(_MSC_VER)
#               if defined(STATIC_LINKED)
#                       define SWIGEXPORT(a) a
#               else
#                       define SWIGEXPORT(a) __declspec(dllexport) a
#               endif
#       else
#               if defined(__BORLANDC__)
#                       define SWIGEXPORT(a) a _export
#               else
#                       define SWIGEXPORT(a) a
#       endif
#endif
#else
#       define SWIGEXPORT(a) a
#endif

#ifdef SWIG_GLOBAL
#define SWIGRUNTIME(a) SWIGEXPORT(a)
#else
#define SWIGRUNTIME(a) static a
#endif



#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *);

typedef struct swig_type_info {
  const char             *name;                 
  swig_converter_func     converter;
  const char             *str;
  struct swig_type_info  *next;
  struct swig_type_info  *prev;
  void                   *clientdata;	
} swig_type_info;

#ifdef SWIG_NOINCLUDE
SWIGEXPORT(swig_type_info *) SWIG_TypeRegister(swig_type_info *);
SWIGEXPORT(swig_type_info *) SWIG_TypeCheck(char *c, swig_type_info *);
SWIGEXPORT(void *) SWIG_TypeCast(swig_type_info *, void *);
SWIGEXPORT(swig_type_info *) SWIG_TypeQuery(const char *);
SWIGEXPORT(void) SWIG_TypeClientData(swig_type_info *, void *);
#else

static swig_type_info *swig_type_list = 0;

/* Register a type mapping with the type-checking */
SWIGRUNTIME(swig_type_info *)
SWIG_TypeRegister(swig_type_info *ti)
{
  swig_type_info *tc, *head, *ret, *next;
  /* Check to see if this type has already been registered */
  tc = swig_type_list;
  while (tc) {
    if (strcmp(tc->name, ti->name) == 0) {
      /* Already exists in the table.  Just add additional types to the list */
      head = tc;
      next = tc->next;
      goto l1;
    }
    tc = tc->prev;
  }
  head = ti;
  next = 0;

  /* Place in list */
  ti->prev = swig_type_list;
  swig_type_list = ti;

  /* Build linked lists */
 l1:
  ret = head;
  tc = ti + 1;
  /* Patch up the rest of the links */
  while (tc->name) {
    head->next = tc;
    tc->prev = head;
    head = tc;
    tc++;
  }
  head->next = next;
  return ret;
}

/* Check the typename */
SWIGRUNTIME(swig_type_info *) 
SWIG_TypeCheck(char *c, swig_type_info *ty)
{
  swig_type_info *s;
  if (!ty) return 0;        /* Void pointer */
  s = ty->next;             /* First element always just a name */
  while (s) {
    if (strcmp(s->name,c) == 0) {
      if (s == ty->next) return s;
      /* Move s to the top of the linked list */
      s->prev->next = s->next;
      if (s->next) {
	s->next->prev = s->prev;
      }
      /* Insert s as second element in the list */
      s->next = ty->next;
      if (ty->next) ty->next->prev = s;
      ty->next = s;
      return s;
    }
    s = s->next;
  }
  return 0;
}

/* Cast a pointer (needed for C++ inheritance */
SWIGRUNTIME(void *) 
SWIG_TypeCast(swig_type_info *ty, void *ptr) 
{
  if ((!ty) || (!ty->converter)) return ptr;
  return (*ty->converter)(ptr);
}

/* Search for a swig_type_info structure */
SWIGRUNTIME(swig_type_info *)
SWIG_TypeQuery(const char *name) {
  swig_type_info *ty = swig_type_list;
  while (ty) {
    if (ty->str && (strcmp(name,ty->str) == 0)) return ty;
    if (ty->name && (strcmp(name,ty->name) == 0)) return ty;
    ty = ty->prev;
  }
  return 0;
}

/* Set the clientdata field for a type */
SWIGRUNTIME(void)
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_type_info *tc, *equiv;
  if (ti->clientdata) return;
  ti->clientdata = clientdata;
  equiv = ti->next;
  while (equiv) {
    if (!equiv->converter) {
      tc = swig_type_list;
      while (tc) {
	if ((strcmp(tc->name, equiv->name) == 0))
	  SWIG_TypeClientData(tc,clientdata);
	tc = tc->prev;
      }
    }
    equiv = equiv->next;
  }
}
#endif

#ifdef __cplusplus
}

#endif




/* -----------------------------------------------------------------------------
 * perl5.swg
 *
 * Perl5 runtime library
 * $Header: /cvs/projects/SWIG/Lib/perl5/Attic/perlrun.swg,v 1.1.2.5 2001/12/10 20:34:03 beazley Exp $
 * ----------------------------------------------------------------------------- */

#define SWIGPERL
#define SWIGPERL5
#ifdef __cplusplus
/* Needed on some windows machines---since MS plays funny
   games with the header files under C++ */
#include <math.h>
#include <stdlib.h>
extern "C" {
#endif
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

/* Get rid of free and malloc defined by perl */
#undef free
#undef malloc

#ifndef pTHX_
#define pTHX_
#endif

#include <string.h>
#ifdef __cplusplus
}
#endif

/* Note: SwigMagicFuncHack is a typedef used to get the C++
   compiler to just shut up already */

#ifdef PERL_OBJECT
#define MAGIC_PPERL  CPerlObj *pPerl = (CPerlObj *) this;
typedef int (CPerlObj::*SwigMagicFunc)(SV *, MAGIC *);

#ifdef __cplusplus
extern "C" {
#endif
typedef int (CPerlObj::*SwigMagicFuncHack)(SV *, MAGIC *);
#ifdef __cplusplus
}
#endif

#define SWIG_MAGIC(a,b) (SV *a, MAGIC *b)
#define SWIGCLASS_STATIC
#else
#define MAGIC_PPERL
#define SWIGCLASS_STATIC static
#ifndef MULTIPLICITY
#define SWIG_MAGIC(a,b) (SV *a, MAGIC *b)
typedef int (*SwigMagicFunc)(SV *, MAGIC *);

#ifdef __cplusplus
extern "C" {
#endif
typedef int (*SwigMagicFuncHack)(SV *, MAGIC *);
#ifdef __cplusplus
}
#endif


#else
#define SWIG_MAGIC(a,b) (struct interpreter *interp, SV *a, MAGIC *b)
typedef int (*SwigMagicFunc)(struct interpreter *, SV *, MAGIC *);
#ifdef __cplusplus
extern "C" {
#endif
typedef int (*SwigMagicFuncHack)(struct interpreter *, SV *, MAGIC *);
#ifdef __cplusplus
}
#endif

#endif
#endif

#if defined(WIN32) && defined(PERL_OBJECT) && !defined(PerlIO_exportFILE)
#define PerlIO_exportFILE(fh,fl) (FILE*)(fh)
#endif

/* Modifications for newer Perl 5.005 releases */

#if !defined(PERL_REVISION) || ((PERL_REVISION >= 5) && ((PERL_VERSION < 5) || ((PERL_VERSION == 5) && (PERL_SUBVERSION < 50))))
#ifndef PL_sv_yes
#define PL_sv_yes sv_yes
#endif
#ifndef PL_sv_undef
#define PL_sv_undef sv_undef
#endif
#ifndef PL_na
#define PL_na na
#endif
#endif

#include <stdlib.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifdef SWIG_NOINCLUDE

#ifndef PERL_OBJECT
extern int SWIG_ConvertPtr(SV *, void **, swig_type_info *);
extern void SWIG_MakePtr(SV *, void *, swig_type_info *);
#else
extern int _SWIG_ConvertPtr(CPerlObj *, SV *, void **, swig_type_info *);
extern void _SWIG_MakePtr(CPerlObj *, SV *, void *, swig_type_info *);
#define SWIG_ConvertPtr(a,b,c) _SWIG_ConvertPtr(pPerl,a,b,c)
#define SWIG_MakePtr(a,b,c) _SWIG_MakePtr(pPerl,a,b,c)
#endif

#else

/* Function for getting a pointer value */

#ifndef PERL_OBJECT
SWIGRUNTIME(int) 
SWIG_ConvertPtr(SV *sv, void **ptr, swig_type_info *_t)
#else
#define SWIG_ConvertPtr(a,b,c) _SWIG_ConvertPtr(pPerl,a,b,c)
SWIGRUNTIME(int)
_SWIG_ConvertPtr(CPerlObj *pPerl, SV *sv, void **ptr, swig_type_info *_t)
#endif
{
  char *_c;
  swig_type_info *tc;
  IV   tmp;

  /* If magical, apply more magic */
  if (SvGMAGICAL(sv))
    mg_get(sv);

  /* Check to see if this is an object */
  if (sv_isobject(sv)) {
    SV *tsv = (SV*) SvRV(sv);
    if ((SvTYPE(tsv) == SVt_PVHV)) {
      MAGIC *mg;
      if (SvMAGICAL(tsv)) {
	mg = mg_find(tsv,'P');
	if (mg) {
	  SV *rsv = mg->mg_obj;
	  if (sv_isobject(rsv)) {
	    tmp = SvIV((SV*)SvRV(rsv));
	  }
	}
      } else {
	return -1;
      }
    } else {
      tmp = SvIV((SV*)SvRV(sv));
    }
    if (!_t) {
      *(ptr) = (void *) tmp;
      return 0;
    }
  } else if (! SvOK(sv)) {            /* Check for undef */
    *(ptr) = (void *) 0;
    return 0;
  } else if (SvTYPE(sv) == SVt_RV) {  /* Check for NULL pointer */
    *(ptr) = (void *) 0;
    if (!SvROK(sv)) 
      return 0;
    else
      return -1;
  } else {                            /* Don't know what it is */
      *(ptr) = (void *) 0;
      return -1;
  }
  if (_t) {
    /* Now see if the types match */      
    _c = HvNAME(SvSTASH(SvRV(sv)));
    tc = SWIG_TypeCheck(_c,_t);
    if (!tc) {
      *ptr = (void *) tmp;
      return -1;
    }
    *ptr = SWIG_TypeCast(tc,(void *)tmp);
    return 0;
  }
  *ptr = (void *) tmp;
  return 0;
}
#ifndef PERL_OBJECT
SWIGRUNTIME(void) 
SWIG_MakePtr(SV *sv, void *ptr, swig_type_info *t)
#else
#define SWIG_MakePtr(a,b,c) _SWIG_MakePtr(pPerl,a,b,c)
SWIGRUNTIME(void)
_SWIG_MakePtr(CPerlObj *pPerl, SV *sv, void *ptr, swig_type_info *t)
#endif
{
  sv_setref_pv(sv, (char *) t->name, ptr);
}

#endif

typedef XS(SwigPerlWrapper);
typedef SwigPerlWrapper *SwigPerlWrapperPtr;

/* Structure for command table */
typedef struct {
  const char         *name;
  SwigPerlWrapperPtr  wrapper;
} swig_command_info;

/* Information for constant table */

#define SWIG_INT     1
#define SWIG_FLOAT   2
#define SWIG_STRING  3
#define SWIG_POINTER 4
#define SWIG_BINARY  5

/* Constant information structure */
typedef struct swig_constant_info {
    int              type;
    const char      *name;
    long             lvalue;
    double           dvalue;
    void            *pvalue;
    swig_type_info **ptype;
} swig_constant_info;

#ifdef __cplusplus
}
#endif

/* Structure for variable table */
typedef struct {
  const char   *name;
  SwigMagicFunc   set;
  SwigMagicFunc   get;
} swig_variable_info;

/* Magic variable code */
#ifndef PERL_OBJECT
#define swig_create_magic(s,a,b,c) _swig_create_magic(s,a,b,c)
  #ifndef MULTIPLICITY 
       static void _swig_create_magic(SV *sv, char *name, int (*set)(SV *, MAGIC *), int \
(*get)(SV *,MAGIC *)) { 
  #else 
       static void _swig_create_magic(SV *sv, char *name, int (*set)(struct interpreter*,\
 SV *, MAGIC *), int (*get)(struct interpreter*, SV *,MAGIC *)) { 
  #endif 
#else
#define swig_create_magic(s,a,b,c) _swig_create_magic(pPerl,s,a,b,c)
static void _swig_create_magic(CPerlObj *pPerl, SV *sv, const char *name, int (CPerlObj::*set)(SV *, MAGIC *), int (CPerlObj::*get)(SV *, MAGIC *)) {
#endif
  MAGIC *mg;
  sv_magic(sv,sv,'U',(char *) name,strlen(name));
  mg = mg_find(sv,'U');
  mg->mg_virtual = (MGVTBL *) malloc(sizeof(MGVTBL));
  mg->mg_virtual->svt_get = (SwigMagicFuncHack) get;
  mg->mg_virtual->svt_set = (SwigMagicFuncHack) set;
  mg->mg_virtual->svt_len = 0;
  mg->mg_virtual->svt_clear = 0;
  mg->mg_virtual->svt_free = 0;
}







/* -------- TYPES TABLE (BEGIN) -------- */

#define  SWIGTYPE_p_SUFFIX_TREE swig_types[0] 
#define  SWIGTYPE_p_NODE swig_types[1] 
#define  SWIGTYPE_p_SUFFIXTREENODE swig_types[2] 
static swig_type_info *swig_types[4];

/* -------- TYPES TABLE (END) -------- */

#define SWIG_init    boot_SuffixTree

#define SWIG_name   "SuffixTree::boot_SuffixTree"
#define SWIG_prefix "SuffixTree::"

#ifdef __cplusplus
extern "C"
#endif
#ifndef PERL_OBJECT
#ifndef MULTIPLICITY
SWIGEXPORT(void) SWIG_init (CV* cv);
#else
SWIGEXPORT(void) SWIG_init (pTHXo_ CV* cv);
#endif
#else
SWIGEXPORT(void) SWIG_init (CV *cv, CPerlObj *);
#endif

#ifdef PERL_OBJECT
#define MAGIC_CLASS _wrap_SuffixTree_var::
class _wrap_SuffixTree_var : public CPerlObj {
public:
#else
#define MAGIC_CLASS
#endif
SWIGCLASS_STATIC int swig_magic_readonly(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    sv = sv; mg = mg;
    croak("Value is read-only.");
    return 0;
}
SWIGCLASS_STATIC int _wrap_set_ST_ERROR(pTHX_ SV* sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    ST_ERROR = (unsigned long ) SvIV(sv);
    return 1;
}


SWIGCLASS_STATIC int _wrap_val_ST_ERROR(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(sv, (IV) ST_ERROR);
    return 1;
}




#ifdef PERL_OBJECT
};
#endif

#ifdef __cplusplus
extern "C" {
#endif
XS(_wrap_SUFFIXTREENODE_sons_set) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_sons_set(self,sons);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_sons_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    {
        if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SUFFIXTREENODE) < 0) {
            croak("Type error in argument 2 of SUFFIXTREENODE_sons_set. Expected %s", SWIGTYPE_p_SUFFIXTREENODE->name);
        }
    }
    if (arg1) arg1->sons = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_sons_get) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_sons_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_sons_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (struct SUFFIXTREENODE *) (arg1->sons);
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SUFFIXTREENODE);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_right_sibling_set) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_right_sibling_set(self,right_sibling);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_right_sibling_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    {
        if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SUFFIXTREENODE) < 0) {
            croak("Type error in argument 2 of SUFFIXTREENODE_right_sibling_set. Expected %s", SWIGTYPE_p_SUFFIXTREENODE->name);
        }
    }
    if (arg1) arg1->right_sibling = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_right_sibling_get) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_right_sibling_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_right_sibling_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (struct SUFFIXTREENODE *) (arg1->right_sibling);
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SUFFIXTREENODE);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_left_sibling_set) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_left_sibling_set(self,left_sibling);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_left_sibling_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    {
        if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SUFFIXTREENODE) < 0) {
            croak("Type error in argument 2 of SUFFIXTREENODE_left_sibling_set. Expected %s", SWIGTYPE_p_SUFFIXTREENODE->name);
        }
    }
    if (arg1) arg1->left_sibling = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_left_sibling_get) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_left_sibling_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_left_sibling_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (struct SUFFIXTREENODE *) (arg1->left_sibling);
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SUFFIXTREENODE);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_father_set) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_father_set(self,father);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_father_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    {
        if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SUFFIXTREENODE) < 0) {
            croak("Type error in argument 2 of SUFFIXTREENODE_father_set. Expected %s", SWIGTYPE_p_SUFFIXTREENODE->name);
        }
    }
    if (arg1) arg1->father = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_father_get) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_father_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_father_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (struct SUFFIXTREENODE *) (arg1->father);
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SUFFIXTREENODE);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_suffix_link_set) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_suffix_link_set(self,suffix_link);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_suffix_link_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    {
        if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SUFFIXTREENODE) < 0) {
            croak("Type error in argument 2 of SUFFIXTREENODE_suffix_link_set. Expected %s", SWIGTYPE_p_SUFFIXTREENODE->name);
        }
    }
    if (arg1) arg1->suffix_link = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_suffix_link_get) {
    NODE *arg1 ;
    struct SUFFIXTREENODE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_suffix_link_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_suffix_link_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (struct SUFFIXTREENODE *) (arg1->suffix_link);
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SUFFIXTREENODE);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_path_position_set) {
    NODE *arg1 ;
    unsigned long arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_path_position_set(self,path_position);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_path_position_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    arg2 = (unsigned long ) SvIV(ST(1));
    if (arg1) arg1->path_position = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_path_position_get) {
    NODE *arg1 ;
    unsigned long result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_path_position_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_path_position_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (unsigned long ) (arg1->path_position);
    
    ST(argvi) = sv_newmortal();
    sv_setiv(ST(argvi++), (IV) result);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_edge_label_start_set) {
    NODE *arg1 ;
    unsigned long arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_edge_label_start_set(self,edge_label_start);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_edge_label_start_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    arg2 = (unsigned long ) SvIV(ST(1));
    if (arg1) arg1->edge_label_start = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_edge_label_start_get) {
    NODE *arg1 ;
    unsigned long result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_edge_label_start_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_edge_label_start_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (unsigned long ) (arg1->edge_label_start);
    
    ST(argvi) = sv_newmortal();
    sv_setiv(ST(argvi++), (IV) result);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_edge_label_end_set) {
    NODE *arg1 ;
    unsigned long arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREENODE_edge_label_end_set(self,edge_label_end);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_edge_label_end_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    arg2 = (unsigned long ) SvIV(ST(1));
    if (arg1) arg1->edge_label_end = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREENODE_edge_label_end_get) {
    NODE *arg1 ;
    unsigned long result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREENODE_edge_label_end_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREENODE_edge_label_end_get. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    result = (unsigned long ) (arg1->edge_label_end);
    
    ST(argvi) = sv_newmortal();
    sv_setiv(ST(argvi++), (IV) result);
    XSRETURN(argvi);
}


XS(_wrap_new_SUFFIXTREENODE) {
    NODE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) 
    croak("Usage: new_SUFFIXTREENODE();");
    result = (NODE *)(NODE *) calloc(1, sizeof(NODE));
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_NODE);
    XSRETURN(argvi);
}


XS(_wrap_delete_SUFFIXTREENODE) {
    NODE *arg1 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: delete_SUFFIXTREENODE(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 1 of delete_SUFFIXTREENODE. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    free((char *) arg1);
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_e_set) {
    SUFFIX_TREE *arg1 ;
    unsigned long arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREE_e_set(self,e);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_e_set. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    arg2 = (unsigned long ) SvIV(ST(1));
    if (arg1) arg1->e = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_e_get) {
    SUFFIX_TREE *arg1 ;
    unsigned long result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREE_e_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_e_get. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    result = (unsigned long ) (arg1->e);
    
    ST(argvi) = sv_newmortal();
    sv_setiv(ST(argvi++), (IV) result);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_tree_string_set) {
    SUFFIX_TREE *arg1 ;
    char *arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREE_tree_string_set(self,tree_string);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_tree_string_set. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    if (!SvOK((SV*) ST(1))) arg2 = 0;
    else arg2 = (char *) SvPV(ST(1), PL_na);
    {
        if (arg1->tree_string) free((char*)arg1->tree_string);
        arg1->tree_string = (char *) malloc(strlen(arg2)+1);
        strcpy((char*)arg1->tree_string,arg2);
    }
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_tree_string_get) {
    SUFFIX_TREE *arg1 ;
    char *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREE_tree_string_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_tree_string_get. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    result = (char *) (arg1->tree_string);
    
    ST(argvi) = sv_newmortal();
    sv_setpv((SV*)ST(argvi++), (char *) result);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_length_set) {
    SUFFIX_TREE *arg1 ;
    unsigned long arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREE_length_set(self,length);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_length_set. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    arg2 = (unsigned long ) SvIV(ST(1));
    if (arg1) arg1->length = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_length_get) {
    SUFFIX_TREE *arg1 ;
    unsigned long result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREE_length_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_length_get. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    result = (unsigned long ) (arg1->length);
    
    ST(argvi) = sv_newmortal();
    sv_setiv(ST(argvi++), (IV) result);
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_root_set) {
    SUFFIX_TREE *arg1 ;
    NODE *arg2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: SUFFIXTREE_root_set(self,root);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_root_set. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    {
        if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_NODE) < 0) {
            croak("Type error in argument 2 of SUFFIXTREE_root_set. Expected %s", SWIGTYPE_p_NODE->name);
        }
    }
    if (arg1) arg1->root = arg2;
    
    
    XSRETURN(argvi);
}


XS(_wrap_SUFFIXTREE_root_get) {
    SUFFIX_TREE *arg1 ;
    NODE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: SUFFIXTREE_root_get(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of SUFFIXTREE_root_get. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    result = (NODE *) (arg1->root);
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_NODE);
    XSRETURN(argvi);
}


XS(_wrap_new_SUFFIXTREE) {
    SUFFIX_TREE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) 
    croak("Usage: new_SUFFIXTREE();");
    result = (SUFFIX_TREE *)(SUFFIX_TREE *) calloc(1, sizeof(SUFFIX_TREE));
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SUFFIX_TREE);
    XSRETURN(argvi);
}


XS(_wrap_delete_SUFFIXTREE) {
    SUFFIX_TREE *arg1 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: delete_SUFFIXTREE(self);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of delete_SUFFIXTREE. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    free((char *) arg1);
    
    
    XSRETURN(argvi);
}


XS(_wrap_ST_CreateTree) {
    char *arg1 ;
    unsigned long arg2 ;
    SUFFIX_TREE *result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) 
    croak("Usage: ST_CreateTree(str,length);");
    if (!SvOK((SV*) ST(0))) arg1 = 0;
    else arg1 = (char *) SvPV(ST(0), PL_na);
    arg2 = (unsigned long ) SvIV(ST(1));
    result = (SUFFIX_TREE *)ST_CreateTree((char const *)arg1,arg2);
    
    ST(argvi) = sv_newmortal();
    SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SUFFIX_TREE);
    XSRETURN(argvi);
}


XS(_wrap_ST_FindSubstring) {
    SUFFIX_TREE *arg1 ;
    char *arg2 ;
    unsigned long arg3 ;
    unsigned long result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) 
    croak("Usage: ST_FindSubstring(tree,W,P);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of ST_FindSubstring. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    if (!SvOK((SV*) ST(1))) arg2 = 0;
    else arg2 = (char *) SvPV(ST(1), PL_na);
    arg3 = (unsigned long ) SvIV(ST(2));
    result = (unsigned long )ST_FindSubstring(arg1,arg2,arg3);
    
    ST(argvi) = sv_newmortal();
    sv_setiv(ST(argvi++), (IV) result);
    XSRETURN(argvi);
}


XS(_wrap_ST_PrintTree) {
    SUFFIX_TREE *arg1 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: ST_PrintTree(tree);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of ST_PrintTree. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    ST_PrintTree(arg1);
    
    
    XSRETURN(argvi);
}


XS(_wrap_ST_DeleteTree) {
    SUFFIX_TREE *arg1 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: ST_DeleteTree(tree);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of ST_DeleteTree. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    ST_DeleteTree(arg1);
    
    
    XSRETURN(argvi);
}


XS(_wrap_ST_SelfTest) {
    SUFFIX_TREE *arg1 ;
    unsigned long result;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) 
    croak("Usage: ST_SelfTest(tree);");
    {
        if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_SUFFIX_TREE) < 0) {
            croak("Type error in argument 1 of ST_SelfTest. Expected %s", SWIGTYPE_p_SUFFIX_TREE->name);
        }
    }
    result = (unsigned long )ST_SelfTest(arg1);
    
    ST(argvi) = sv_newmortal();
    sv_setiv(ST(argvi++), (IV) result);
    XSRETURN(argvi);
}



/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static swig_type_info _swigt__p_SUFFIX_TREE[] = {{"_p_SUFFIX_TREE", 0, "SUFFIX_TREE *"},{"_p_SUFFIX_TREE"},{0}};
static swig_type_info _swigt__p_NODE[] = {{"_p_NODE", 0, "NODE *"},{"_p_NODE"},{"_p_SUFFIXTREENODE"},{0}};
static swig_type_info _swigt__p_SUFFIXTREENODE[] = {{"_p_SUFFIXTREENODE", 0, "struct SUFFIXTREENODE *"},{"_p_SUFFIXTREENODE"},{"_p_NODE"},{0}};

static swig_type_info *swig_types_initial[] = {
_swigt__p_SUFFIX_TREE, 
_swigt__p_NODE, 
_swigt__p_SUFFIXTREENODE, 
0
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_constant_info swig_constants[] = {
{0}
};
#ifdef __cplusplus
}
#endif
static swig_variable_info swig_variables[] = {
    { "SuffixTree::ST_ERROR", MAGIC_CLASS _wrap_set_ST_ERROR, MAGIC_CLASS _wrap_val_ST_ERROR },
{0}
};
static swig_command_info swig_commands[] = {
{"SuffixTree::SUFFIXTREENODE_sons_set", _wrap_SUFFIXTREENODE_sons_set},
{"SuffixTree::SUFFIXTREENODE_sons_get", _wrap_SUFFIXTREENODE_sons_get},
{"SuffixTree::SUFFIXTREENODE_right_sibling_set", _wrap_SUFFIXTREENODE_right_sibling_set},
{"SuffixTree::SUFFIXTREENODE_right_sibling_get", _wrap_SUFFIXTREENODE_right_sibling_get},
{"SuffixTree::SUFFIXTREENODE_left_sibling_set", _wrap_SUFFIXTREENODE_left_sibling_set},
{"SuffixTree::SUFFIXTREENODE_left_sibling_get", _wrap_SUFFIXTREENODE_left_sibling_get},
{"SuffixTree::SUFFIXTREENODE_father_set", _wrap_SUFFIXTREENODE_father_set},
{"SuffixTree::SUFFIXTREENODE_father_get", _wrap_SUFFIXTREENODE_father_get},
{"SuffixTree::SUFFIXTREENODE_suffix_link_set", _wrap_SUFFIXTREENODE_suffix_link_set},
{"SuffixTree::SUFFIXTREENODE_suffix_link_get", _wrap_SUFFIXTREENODE_suffix_link_get},
{"SuffixTree::SUFFIXTREENODE_path_position_set", _wrap_SUFFIXTREENODE_path_position_set},
{"SuffixTree::SUFFIXTREENODE_path_position_get", _wrap_SUFFIXTREENODE_path_position_get},
{"SuffixTree::SUFFIXTREENODE_edge_label_start_set", _wrap_SUFFIXTREENODE_edge_label_start_set},
{"SuffixTree::SUFFIXTREENODE_edge_label_start_get", _wrap_SUFFIXTREENODE_edge_label_start_get},
{"SuffixTree::SUFFIXTREENODE_edge_label_end_set", _wrap_SUFFIXTREENODE_edge_label_end_set},
{"SuffixTree::SUFFIXTREENODE_edge_label_end_get", _wrap_SUFFIXTREENODE_edge_label_end_get},
{"SuffixTree::new_SUFFIXTREENODE", _wrap_new_SUFFIXTREENODE},
{"SuffixTree::delete_SUFFIXTREENODE", _wrap_delete_SUFFIXTREENODE},
{"SuffixTree::SUFFIXTREE_e_set", _wrap_SUFFIXTREE_e_set},
{"SuffixTree::SUFFIXTREE_e_get", _wrap_SUFFIXTREE_e_get},
{"SuffixTree::SUFFIXTREE_tree_string_set", _wrap_SUFFIXTREE_tree_string_set},
{"SuffixTree::SUFFIXTREE_tree_string_get", _wrap_SUFFIXTREE_tree_string_get},
{"SuffixTree::SUFFIXTREE_length_set", _wrap_SUFFIXTREE_length_set},
{"SuffixTree::SUFFIXTREE_length_get", _wrap_SUFFIXTREE_length_get},
{"SuffixTree::SUFFIXTREE_root_set", _wrap_SUFFIXTREE_root_set},
{"SuffixTree::SUFFIXTREE_root_get", _wrap_SUFFIXTREE_root_get},
{"SuffixTree::new_SUFFIXTREE", _wrap_new_SUFFIXTREE},
{"SuffixTree::delete_SUFFIXTREE", _wrap_delete_SUFFIXTREE},
{"SuffixTree::ST_CreateTree", _wrap_ST_CreateTree},
{"SuffixTree::ST_FindSubstring", _wrap_ST_FindSubstring},
{"SuffixTree::ST_PrintTree", _wrap_ST_PrintTree},
{"SuffixTree::ST_DeleteTree", _wrap_ST_DeleteTree},
{"SuffixTree::ST_SelfTest", _wrap_ST_SelfTest},
{0,0}
};

#ifdef __cplusplus
extern "C"
#endif

XS(SWIG_init) {
    dXSARGS;
    int i;
    for (i = 0; swig_types_initial[i]; i++) {
        swig_types[i] = SWIG_TypeRegister(swig_types_initial[i]);
    }
    
    /* Install commands */
    for (i = 0; swig_commands[i].name; i++) {
        newXS((char*) swig_commands[i].name,swig_commands[i].wrapper, (char*)__FILE__);
    }
    
    /* Install variables */
    for (i = 0; swig_variables[i].name; i++) {
        SV *sv;
        sv = perl_get_sv((char*) swig_variables[i].name, TRUE | 0x2);
        sv_setiv(sv, (IV) 0);
        swig_create_magic(sv, (char *) swig_variables[i].name, swig_variables[i].set, swig_variables[i].get);
    }
    
    /* Install constant */
    for (i = 0; swig_constants[i].type; i++) {
        SV *sv;
        sv = perl_get_sv((char*)swig_constants[i].name, TRUE | 0x2);
        switch(swig_constants[i].type) {
            case SWIG_INT:
            sv_setiv(sv, (IV) swig_constants[i].lvalue);
            break;
            case SWIG_FLOAT:
            sv_setnv(sv, (double) swig_constants[i].dvalue);
            break;
            case SWIG_STRING:
            sv_setpv(sv, (char *) swig_constants[i].pvalue);
            break;
            case SWIG_POINTER:
            SWIG_MakePtr(sv, swig_constants[i].pvalue, *(swig_constants[i].ptype));
            break;
            case SWIG_BINARY:
            /*      obj = SWIG_NewPackedObj(swig_constants[i].pvalue, swig_constants[i].lvalue, *(swig_constants[i].ptype)); */
            break;
            default:
            break;
        }
        SvREADONLY_on(sv);
    }
    
    ST(0) = &PL_sv_yes;
    XSRETURN(1);
}

